@@ -147,7 +147,7 @@ static void simple_brightness_applet_on_dispchkbtn_toggled (GtkWidget *button G_
 	if (plugin->priv->keepdispon_active)
 	{
 		simple_brightness_applet_keep_backlight_alive (plugin);
-		plugin->priv->display_keepalive_timeout = g_timeout_add_seconds (10, (GSourceFunc) simple_brightness_applet_keep_backlight_alive, plugin);
+		plugin->priv->display_keepalive_timeout = g_timeout_add_seconds (50, (GSourceFunc) simple_brightness_applet_keep_backlight_alive, plugin);
 		if (plugin->priv->display_keepalive_timeout == 0)
 		{
 			plugin->priv->keepdispon_active = FALSE;
@@ -185,7 +185,7 @@ static void simple_brightness_applet_on_button_clicked (GtkWidget *button, Simpl
 	gtk_widget_hide (gtk_widget_get_toplevel (button));
 
 	plugin->priv->settings_dialog = gtk_dialog_new ();
-	gtk_window_set_title (GTK_WINDOW (plugin->priv->settings_dialog), "Simple Brightness Applet:");
+	gtk_window_set_title (GTK_WINDOW (plugin->priv->settings_dialog), _("Simple Brightness Applet"));
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (plugin->priv->settings_dialog), TRUE);
 
 	settings_button = hildon_gtk_button_new (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH);
@@ -211,7 +211,7 @@ static void simple_brightness_applet_on_tap_and_hold (GtkWidget *widget, SimpleB
 	if (!plugin->priv->keepdispon_active)
 	{
 		simple_brightness_applet_keep_backlight_alive (plugin);
-		plugin->priv->display_keepalive_timeout = g_timeout_add_seconds (10, (GSourceFunc) simple_brightness_applet_keep_backlight_alive, plugin);
+		plugin->priv->display_keepalive_timeout = g_timeout_add_seconds (50, (GSourceFunc) simple_brightness_applet_keep_backlight_alive, plugin);
 		if (!plugin->priv->display_keepalive_timeout)
 		{
 			simple_brightness_applet_show_fail_msg ();
